@@ -9,7 +9,7 @@
 #include "s7.h"
 
 #ifndef _MSC_VER
-static char *realdir(const char *filename)
+static char *realdir(s7_scheme *sc, const char *filename)
 {
   char *path;
   char *p;
@@ -18,7 +18,14 @@ static char *realdir(const char *filename)
     {
       if (access("libc_s7.so", F_OK) != 0)
 	{
-	  fprintf(stderr, "%s needs libc_s7.so (give the explicit pathname)\n", filename); /* env PATH=/home/bil/cl repl */
+	  if ((access("libc.scm", F_OK) == 0) &&
+	      (access("cload.scm", F_OK) == 0))
+	    {
+	      s7_load(sc, "cload.scm");
+	      s7_load(sc, "libc.scm");
+	      return(NULL);
+	    }
+	  fprintf(stderr, "%s needs libc_s7.so (give the explicit repl pathname or build it by running: repl libc.scm)\n", filename); /* env PATH=/home/bil/cl repl */
 	  exit(2);
 	}
       return(NULL);  /* we're in the libc_s7.so directory, I hope (user could start a version of s7 that does not match the local libc_s7.so...) */
@@ -46,8 +53,15 @@ int main(int argc, char **argv)
   sc = s7_init();
   /* fprintf(stderr, "s7: %s\n", S7_DATE); */
 
-  if (argc == 2)
+  if (argc >= 2)
     {
+      if (strcmp(argv[1], "-e") == 0)
+	{
+	  s7_pointer x;
+	  x = s7_eval_c_string(sc, argv[2]);
+	  fprintf(stdout, "%s\n", s7_object_to_c_string(sc, x));
+	  return(0);
+	}
       fprintf(stderr, "load %s\n", argv[1]);
       if (!s7_load(sc, argv[1]))
 	{
@@ -64,7 +78,7 @@ int main(int argc, char **argv)
       s7_add_to_load_path(sc, S7_LOAD_PATH);
 #else
       char *dir; 
-      dir = realdir(argv[0]);
+      dir = realdir(sc, argv[0]);
       if (dir)
 	{
 	  s7_add_to_load_path(sc, dir);
