@@ -14,7 +14,6 @@
 	  (symbol-table))
 
 ;(define debugging (provided? 'debugging))
-;(when (provided? 'profiling) (load "profile.scm"))
 
 ;(set! (hook-functions *load-hook*) (list (lambda (hook) (format () "loading ~S...~%" (hook 'name)))))
 
@@ -629,7 +628,6 @@
 			  'provide 'call-with-output-string 
 			  'checked-hash-table
 			  'with-output-to-string 
-			  's7-version 
 			  'dilambda?
 			  'hook-functions 
 			  'c-pointer->list 'c-pointer-info 'c-pointer-type 'c-pointer-weak1 'c-pointer-weak2
@@ -806,7 +804,7 @@
       (args (vector "-123" "1234" "-3/4" "-1" "1/2" "(expt 2 32)" "4294967297" "1001" "10001" ;;"(+ a 1)" "(- a 1)" "(logand (ash 1 b) a)"
 		    "\"ho\"" ":ho" "'ho" "(list 1)" "(list 1 2)" "(cons 1 2)" "'()" "(list (list 1 2))" "(list (list 1))" "(list ())" "=>" 
 		    "#f" "#t" "()" "#()" "\"\"" "'#()" ; ":write" -- not this because sr2 calls write and this can be an arg to sublet redefining write
-		    ":readable" ":rest" ":allow-other-keys" ":a" ;"__func__"
+		    ":readable" ":rest" ":allow-other-keys" ":a" 
 		    "1/0+i" "0+0/0i" "0+1/0i" "1+0/0i" "0/0+0/0i" "0/0+i" "+nan.0-3i" "+inf.0-nan.0i"
 		    "cons" "''2" "\"ra\"" 
 		    "#\\a" "#\\A" "\"str1\"" "\"STR1\"" "#\\0"
