@@ -532,7 +532,7 @@ int main(int argc, char **argv)
   if (!s7_is_eq(s7_f(sc), s7_f(sc))) 
     {fprintf(stderr, "%d: (eq? %s %s) -> #f?\n", __LINE__, s1 = TO_STR(s7_f(sc)), s2 = TO_STR(s7_f(sc))); free(s1); free(s2);}
 
-  if (!s7_is_eqv(s7_f(sc), s7_f(sc))) 
+  if (!s7_is_eqv(sc, s7_f(sc), s7_f(sc))) 
     {fprintf(stderr, "%d: (eqv? %s %s) -> #f?\n", __LINE__, s1 = TO_STR(s7_f(sc)), s2 = TO_STR(s7_f(sc))); free(s1); free(s2);}
 
   if (!s7_is_equal(sc, s7_f(sc), s7_f(sc))) 
@@ -544,7 +544,7 @@ int main(int argc, char **argv)
   if (s7_is_eq(s7_eof_object(sc), s7_undefined(sc)))
     {fprintf(stderr, "%d: (eq? %s %s) -> #t?\n", __LINE__, s1 = TO_STR(s7_eof_object(sc)), s2 = TO_STR(s7_undefined(sc))); free(s1); free(s2);}
 
-  if (s7_is_eqv(s7_eof_object(sc), s7_undefined(sc)))
+  if (s7_is_eqv(sc, s7_eof_object(sc), s7_undefined(sc)))
     {fprintf(stderr, "%d: (eqv? %s %s) -> #t?\n", __LINE__, s1 = TO_STR(s7_eof_object(sc)), s2 = TO_STR(s7_undefined(sc))); free(s1); free(s2);}
 
   if (s7_is_equal(sc, s7_eof_object(sc), s7_undefined(sc)))
@@ -567,6 +567,7 @@ int main(int argc, char **argv)
       fprintf(stderr, "fake_cell is ok?\n");
     if (!s7_is_provided(sc, "debugging"))
       s7_object_to_c_string(sc, (s7_pointer)x);
+    free(x);
   }
   if (s7_is_c_pointer(s7_t(sc)))
     {fprintf(stderr, "%d: %s is a raw c pointer?\n", __LINE__, s1 = TO_STR(s7_t(sc))); free(s1);}
@@ -1079,6 +1080,22 @@ int main(int argc, char **argv)
     if (s7_integer(p) != 9)
       {fprintf(stderr, "%d: (eval '(+ 2 3 4)) is %s?\n", __LINE__, s1 = TO_STR(p)); free(s1);}
     s7_gc_on(sc, true);
+
+    p = s7_eval(sc, s7_cons(sc, s7_make_symbol(sc, "+"), /* s7.html example */
+               s7_cons(sc, s7_make_integer(sc, 1),
+                  s7_cons(sc, s7_make_integer(sc, 2), s7_nil(sc)))), 
+               s7_nil(sc));
+    if (s7_integer(p) != 3)
+       {fprintf(stderr, "%d: (eval '(+ 1 2)) is %s?\n", __LINE__, s1 = TO_STR(p)); free(s1);}
+    p = s7_eval(sc, s7_cons(sc, s7_make_symbol(sc, "+"), /* s7.html example */
+               s7_cons(sc, s7_make_integer(sc, 1),
+                  s7_cons(sc, s7_make_integer(sc, 3), s7_nil(sc)))), 
+               s7_rootlet(sc));
+    if (s7_integer(p) != 4)
+       {fprintf(stderr, "%d: (eval '(+ 1 3)) is %s?\n", __LINE__, s1 = TO_STR(p)); free(s1);}
+    p = s7_eval_c_string(sc, "(+ 2 3)");
+    if (s7_integer(p) != 5)
+       {fprintf(stderr, "%d: (eval-string '(+ 2 3)) is %s?\n", __LINE__, s1 = TO_STR(p)); free(s1);}
   }
 
   s7_for_each_symbol_name(sc, symbol_func, NULL);
