@@ -469,7 +469,7 @@
 		 (value (cdr binding)))
 	     (when (and (procedure? value)
 			(let? (funclet value)))
-	       (let ((file (let ((addr (with-let (funclet value) __func__)))
+	       (let ((file (let ((addr (with-let (funclet value) (*function*))))
 			     ;; this misses scheme-side pws because their environment is (probably) the global env
 			     (and (pair? addr)
 				  (pair? (cdr addr))
@@ -1624,6 +1624,8 @@
 
 (html-check '("sndlib.html" "snd.html" "extsnd.html" "grfsnd.html" "sndclm.html" "sndscm.html" "fm.html" "s7.html" "index.html"))
 
+(when (> (*s7* 'profile) 0)
+  (show-profile 200))
 (#_exit)
 
 
