@@ -328,4 +328,6 @@
 
 ;;; --------------------------------------------------------------------------------
 
+(when (> (*s7* 'profile) 0)
+  (show-profile 100))
 (exit)
