@@ -804,5 +804,7 @@
 
 (tvcop)
 
+(when (> (*s7* 'profile) 0)
+  (show-profile 200))
 (exit)
 
